@@ -20,8 +20,6 @@ use ipl\Validator\CallbackValidator;
 use ipl\Web\FormDecorator\IcingaFormDecorator;
 use ipl\Web\Widget\Icon;
 use Iterator;
-use LimitIterator;
-use NoRewindIterator;
 use Traversable;
 
 use function ipl\Stdlib\iterable_value_first;
@@ -163,9 +161,9 @@ class AddCommentForm extends CommandForm
         }
 
         $granted->rewind(); // Forwards the pointer to the first element
-        while ($granted->valid()) {
+        if ($granted->valid()) {
             // Chunk objects to avoid timeouts with large sets
-            yield $command->setObjects(new LimitIterator(new NoRewindIterator($granted), 0, 500));
+            yield $command->setObjects($granted)->setChunkSize(500);
         }
     }
 }
