@@ -16,8 +16,6 @@ use ipl\Orm\Model;
 use ipl\Web\FormDecorator\IcingaFormDecorator;
 use ipl\Web\Widget\Icon;
 use Iterator;
-use LimitIterator;
-use NoRewindIterator;
 use Traversable;
 
 use function ipl\Stdlib\iterable_value_first;
@@ -154,9 +152,9 @@ class ProcessCheckResultForm extends CommandForm
         $command->setPerformanceData($this->getValue('perfdata'));
 
         $granted->rewind(); // Forwards the pointer to the first element
-        while ($granted->valid()) {
+        if ($granted->valid()) {
             // Chunk objects to avoid timeouts with large sets
-            yield $command->setObjects(new LimitIterator(new NoRewindIterator($granted), 0, 250));
+            yield $command->setObjects($granted)->setChunkSize(250);
         }
     }
 }
