@@ -12,8 +12,6 @@ use Icinga\Web\Notification;
 use ipl\Orm\Model;
 use ipl\Web\Widget\Icon;
 use Iterator;
-use LimitIterator;
-use NoRewindIterator;
 use Traversable;
 
 use function ipl\Stdlib\iterable_value_first;
@@ -77,9 +75,9 @@ class RemoveAcknowledgementForm extends CommandForm
         $command->setAuthor($this->getAuth()->getUser()->getUsername());
 
         $granted->rewind(); // Forwards the pointer to the first element
-        while ($granted->valid()) {
+        if ($granted->valid()) {
             // Chunk objects to avoid timeouts with large sets
-            yield $command->setObjects(new LimitIterator(new NoRewindIterator($granted), 0, 250));
+            yield $command->setObjects($granted)->setChunkSize(250);
         }
     }
 }
